#!/bin/bash

#-----------------------------------------------------------------------------#
# Automatic test script for Parallel Programming course                       #
#                                                                             #
# Author: Tomasz Gebarowski                                                   #
# Date:   Wed, 14 Jan 2009, 9:41 PM                                          #
#-----------------------------------------------------------------------------#
#                                                                             #
# Script is executing all the applications with different configuration       #
# parameters. Each results is calculated from the median of N-Probes          #
#                                                                             #
# Results are stored into *.out files                                         #
#                                                                             #
#-----------------------------------------------------------------------------#

#-----------------------------------------------------------------------------#
#---------------------------------Configuration-------------------------------#
#-----------------------------------------------------------------------------#


#Numbers of working threads used for testing
PROCS_NUMS="1 2 3 4 5"

#Tested Application Name
APP_NAME="game_app"

#MPI runtime
MPI_RUN="mpirun"

#Result file
FILE_RESULTS="gol_results.out"

#Median script path
MEDIAN_SCRIPT="./median.awk"


#Number of probes for Median
PROBES=5
 
#---------------------- Game of Life Configuration ---------------------------#

# Static

#Board size 
GOL_BOARD_SIZE="100 500 1000"
#Seed for GoL
GOL_SEED=12345
#Iterations
GOL_STEPS=100

#----------------------------- Testers  ---------------------------------------#

#----------------------------- Prime Searching---------------------------------#


#Generate Columns 
entry="S"

for process_num in $PROCS_NUMS;
do
    entry=$entry";"$process_num
done
echo "$entry" > $FILE_RESULTS;


for board_size in $GOL_BOARD_SIZE;
do
    echo "Testing GoL Board ($board_size x $board_size). Performing $GOL_STEPS steps..."

    entry=""

    for process_num in $PROCS_NUMS;
    do
        echo -n "Performing test for $process_num process(es)..."
        
        cur_time=""

        #Try several times and get median of this results 
        for i in `seq 0 $PROBES`;
        do
            cur_time=`$MPI_RUN -np $process_num -machinefile machines ../$APP_NAME $board_size $GOL_SEED $GOL_STEPS`
            cur_time=`echo "$cur_time" | grep "Measured" | sed -r "s/Measured time: +([0-9]+) msecs/\1/g"`
            time=$cur_time" "
        done
        
        time=`echo "$time" | $MEDIAN_SCRIPT` 
        entry=$entry";"$time
        echo "done"
    done;
    echo "done"
    echo $board_size""$entry >> $FILE_RESULTS
    entry=""
done;
