/**
 * @name:   Game of Life Common File
 *
 * @brief   Common file for GOL-based communication
 *
 * @author: Tomasz Gebarowski <gebarowski@gmail.com>
 * @date:   Wednesday 3 Dec 2008, 8:55 AM
 */
#include <gol_common.h>
#include <string.h>

/** -------------------------------------------------------------------------*/
/** -------------------------- Global Variables -----------------------------*/
/** -------------------------------------------------------------------------*/


static const char *
_g_status_strings[GOL_STATUS_MAX] =
    {
    /* GOL_OK */          "It's ok dude!",
    /* GOL_EOF */         "No more data to read. This is not an error.", 
    /* GOL_ENOMEM */      "Not enough memory. Go and buy some RAM",
    /* GOL_EINVPTR  */    "Invalid Pointer.",
    /* GOL_EOUTB    */    "Index out of bound",
    /* GOL_ECMD */        "Cannot parse command line argument",
    /* GOL_ERROR */       "Generic Error"
    };

/** -------------------------------------------------------------------------*/
/** ------------------------ Function Implementation ------------------------*/
/** -------------------------------------------------------------------------*/


/**
 * @brief Get string representation of status
 *
 * @param  status Status
 *
 * @return Zero terminated string representing status
 */
const char *
gol_status_to_str(gol_status_t status)
{
    return _g_status_strings[status];
}

/**
 * @brief Print status message
 *
 * @param status Status
 */
void
gol_print_status(gol_status_t status)
{
    if ( status == GOL_OK)
    {
        printf("%s\n", _g_status_strings[status]);
    }
    else
    {
        printf("Error: %s\n", _g_status_strings[status]);
    }
}
