/**
 * @name:   Game of Life Common Header
 *
 * @author: Tomasz Gebarowski <gebarowski@gmail.com>
 * @date:   Wednesday 03 Dec 2008, 8:56 AM
 */

#ifndef __GOL_COMMON_H__
#define __GOL_COMMON_H__

#include <stdlib.h>
#include <stdio.h>
#include <config.h>
#include <sys/types.h>


/** -------------------------------------------------------------------------*/
/** --------------------------- Common Typedefs -----------------------------*/
/** -------------------------------------------------------------------------*/

/**
 * @brief Providing Boolean type for C
 */
typedef enum
{ 
    FALSE = 0,
    TRUE = 1
} bool;

/**
 * @brief Error types definition
 */
typedef enum
{
    GOL_OK       = 0,  /* Everything is ok */
    GOL_EOF      = 1,  /* No more data to read. This is not an error */
    GOL_ENOMEM   = 2,  /* Not enough memory */
    GOL_EINVPTR  = 3,  /* Invalid Ptr, probably NULL ptr */
    GOL_EOUTB    = 4,  /* Index out of bound */
    GOL_ECMD     = 5,  /* Error while parsing command line argument */
    GOL_ERROR    = 6,  /* Generic Error */
    GOL_STATUS_MAX
} gol_status_t;


/** -------------------------------------------------------------------------*/
/** --------------------------- API definitions -----------------------------*/
/** -------------------------------------------------------------------------*/

/**
 * @brief Macro definition for debug messages, to be easily removed when not needed
 */
#ifdef RELEASE_MODE
#define gol_debug(s, ...)
#else
#define gol_debug(s, ...) printf(s, ##__VA_ARGS__)
#endif

/**
 * @brief Macro definiton for printing normal messages
 */
#define gol_message(s, ...) printf(s, ##__VA_ARGS__)


/**
 * @brief Modified modulo returning different value for negative numbers
 */
#define gol_mod(n,v) (n<0) ? (((v)+(n)) % (v)) : (n) % (v)

/**
 * @brief Get Neihbouring Rank Macros
 */
#define gol_next_rank(rank,max)  (rank==max-1) ? 0   : (rank+1)
#define gol_prev_rank(rank,max)  (rank==0)   ? max-1 : (rank-1)


/**
 * @brief Get Last array row pointer 
 */
#define gol_last_row_ptr(arr,rows,col_size) (rows<=1) ? &arr[0] : (&arr[col_size * (rows - 1)])

/**
 * @brief Simple macro clearing screen
 */
#define gol_clear()   printf("%c%s",27,"[2J"); printf("%c%s",27,"[1;1H");

/**
 * @brief Get string representation of status2008-11-20 Tomasz Gebarowski <tomasz.gebarowski@wirelesszt.com>

	* src/wzt-scmp-common/wzt_scmp_message_types.h
 *
 * @param  status Status
 *
 * @return Zero terminated string representing status
 */
const char *
gol_status_to_str(gol_status_t status);

/**
 * @brief Print status message
 *
 * @param status Status
 */
void
gol_print_status(gol_status_t status);


#endif /* __GOL_COMMON_H__ */



/** End of gol_common.h */
