/**
 * @name:    Game of Life
 *
 * @brief    Game of Life board implementation
 *
 * @author: Tomasz Gebarowski <gebarowski@gmail.com>
 * @date:   Wednesday 03 Nov 2008, 8:59 AM
 */
#include <gol_common.h>
#include <gol_board.h>
#include <gol_sub_board.h>
#include <limits.h>
#include <string.h>



/** -------------------------------------------------------------------------*/
/** ------------------------ Function Implementation ------------------------*/
/** -------------------------------------------------------------------------*/

/**
 * @brief Allocates memory for Game Board
 */
gol_board_t *
gol_board_create(unsigned int rows,
                 unsigned int cols)
{
    gol_board_t * p_board = malloc(sizeof(gol_board_t));

    if (p_board != NULL)
    {
        p_board->rows = rows;
        p_board->cols = cols;
        p_board->p_arr = calloc(rows * cols, sizeof(unsigned int));

        if (p_board->p_arr == NULL)
        {
            gol_message("Cannot allocate memory for Game Board");
            free(p_board);
            return NULL;
        }
    }
    return p_board;
}

/**
 * @brief Print Game Board
 */
void
gol_board_print(gol_board_t *self)
{
    if (self != NULL)
    {
        if (self->p_arr != NULL)
        {
            int i = 0;
            int j = 0;

            for( i = 0; i < self->rows; i++)
            {
                for( j = 0; j < self->cols; j++)
                {
                    unsigned int state = self->p_arr[self->cols * i +j];
                    printf("%s ",((state == GOL_ALIVE) ? "X" : "0"));
                }
                printf("\n");
            }
        }
    }
}




/**
 * @brief Disposes object 
 */
void
gol_board_dispose(gol_board_t *self)
{
    if (self != NULL)
    {
        if (self->p_arr != NULL)
        {
            free(self->p_arr);
        }

        free(self);
    }
}
