/**
 * @name:   Game of Life Board Header
 *
 * @author: Tomasz Gebarowski <gebarowski@gmail.com>
 * @date:   Wednesday 3 Dec 2008, 8:59 AM
 */

#ifndef __GOL_BOARD_H__
#define __GOL_BOARD_H__

#include <stdlib.h>
#include <stdio.h>

/** -------------------------------------------------------------------------*/
/** --------------------------- Common Typedefs -----------------------------*/
/** -------------------------------------------------------------------------*/

/**
 * @brief Struct representing game board object
 */
typedef struct
{
    unsigned int  * p_arr;   
    unsigned int     rows;
    unsigned int     cols;

} gol_board_t;


/** -------------------------------------------------------------------------*/
/** --------------------------- API definitions -----------------------------*/
/** -------------------------------------------------------------------------*/

/**
 * @brief Allocates memory for Game Board
 *
 * @param self Pointer to game board instance
 *
 * @param rows
 * @param cols
 *
 * @return State of method invocation
 */
gol_board_t *
gol_board_create(unsigned int rows, 
                 unsigned int cols);

/**
 * @brief Print Game Board
 * 
 * @param self Pointer to game board instance
 *
 * @return State of method invocation
 */
void
gol_board_print(gol_board_t *self);


/**
 * @brief Count total alive cells
 *
 * @param self Pointer to Game Board
 * @param p_total_alive (OUT) Place for storing total alive counter
 *
 * @return State of method invocation
 */
gol_status_t
gol_board_count_alive(gol_board_t *self,
                      unsigned long long   *p_total_alive);

/**
 * @brief Dispose Sub Board
 */
void
gol_board_dispose(gol_board_t *self);



#endif /* __GOL_BOARD_H__ */

/** End of gol_board.h */
