/**
 * @name:   Game of Life Board Header
 *
 * @author: Tomasz Gebarowski <gebarowski@gmail.com>
 * @date:   Wednesday 3 Dec 2008, 8:59 AM
 */

#ifndef __GOL_SUB_BOARD_H__
#define __GOL_SUB_BOARD_H__

#include <stdlib.h>
#include <stdio.h>

/** -------------------------------------------------------------------------*/
/** --------------------------- Common Typedefs -----------------------------*/
/** -------------------------------------------------------------------------*/

/**
 * @brief State of single cell
 */
typedef enum
{
    GOL_DEAD  = 0,
    GOL_ALIVE = 1
} gol_state_t;

/**
 * @brief Struct representing game sub_board object
 */
typedef struct
{
    unsigned int  * p_arr;   
    unsigned int  * p_tmp_src; /** Temporary source board */
    unsigned int     rows;
    unsigned int     cols;

} gol_sub_board_t;


/** -------------------------------------------------------------------------*/
/** --------------------------- API definitions -----------------------------*/
/** -------------------------------------------------------------------------*/

/**
 * @brief Allocates memory for Game Board
 *
 * @param self Pointer to game sub_board instance
 *
 * @param rows
 * @param cols
 *
 * @return State of method invocation
 */
gol_sub_board_t *
gol_sub_board_create(unsigned int rows, 
                     unsigned int cols);


/**
 * @brief Initializes Game Board
 *
 * @param self Pointer to game sub_board instance
 *
 * @return State of method invocation
 *
 */
gol_status_t
gol_sub_board_init(gol_sub_board_t *self, 
                   unsigned int seed,
                   unsigned int offset,
                   unsigned int init_popul);


/**
 * @brief Creates Source Sub Board by concatenating
 *        first_row with sub_board and p_last_row
 */
gol_status_t
gol_sub_board_create_tmp_src(gol_sub_board_t *self, 
                             unsigned int *p_first_row,
                             unsigned int *p_last_row,
                             unsigned int  row_size);

/**
 * @brief Runs a single iteration of game logic
 */
gol_status_t
gol_sub_board_run_step(gol_sub_board_t *self);

/**
 * @brief Count total alive cells
 */
gol_status_t
gol_sub_board_count_alive(gol_sub_board_t *self,
                          unsigned int    *p_total_alive);

/**
 * @brief Dispose Sub Board
 */
void
gol_sub_board_dispose(gol_sub_board_t *self);



#endif /* __GOL_SUB_BOARD_H__ */

/** End of gol_sub_board.h */
